==> 1.5.1.tar.gz: hanoi-towers/hanoi_towers/languages/tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation>Ana menüye dön</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation>Klasik arka ışık</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="88"/>
        <source>Random color</source>
        <translation>Çok renkli arka ışık</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="99"/>
        <source>Animation</source>
        <translation>animasyon</translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation>Ana menü</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to any other free space.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation>Göreviniz, sol kuleden farklı boyuttaki diskleri başka bir boş alana aktarmaktır. Kulenin sadece üst sürücüsünü aktarabilirsiniz. Birkaç diski aynı anda transfer edemez ve daha küçük disklere daha büyük diskler yerleştiremezsiniz.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation>Tekrar gösterme:</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation>Hanoi Kuleleri</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation>başlamak</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation>hakkında</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation>çıkış</translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation>başla</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation>hakkında</translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018 Yankovich N. Andrei.</source>
        <translation>QuasarApp ürünü
* Geliştiriciler:
* Programcı: Yankovich N. Andrei.
* Bu oyun LGPLv3 lisansı altında dağıtılmaktadır.
* İletişim: https://github.com/EndrII
* Telif Hakkı (C) 2018 Yankovich N. Andrei.</translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <source>Start</source>
        <translation type="vanished">başla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="vanished">çıkış</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">hakkında</translation>
    </message>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation>seviye </translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation>adım </translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation>Kule yüksekliği:</translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation>Ana menüye dön</translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation>Seviyeyi %0 adımından geçirdiniz ve %1 kilidini açtınız
  Bu lvl için minimum adımlar: %2</translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation>Seviyeyi %0 adımından geçtiniz.
Bu lvl için minimum adımlar:%1</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">ok</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation>Hanoi Kuleleri</translation>
    </message>
</context>
</TS>

==> 1.5.3.tar.gz: hanoi-towers/hanoi_towers/languages/tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>BaseButton</name>
    <message>
        <location filename="../base/BaseButton.qml" line="8"/>
        <source>ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <location filename="../menu/Config.qml" line="28"/>
        <source>Settings</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="35"/>
        <source>Return to main menu</source>
        <translation>Ana menüye dön</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="76"/>
        <source>Standart color</source>
        <translation>Klasik arka ışık</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="87"/>
        <source>Random color</source>
        <translation>Çok renkli arka ışık</translation>
    </message>
    <message>
        <location filename="../menu/Config.qml" line="97"/>
        <source>Animation</source>
        <translation>animasyon</translation>
    </message>
</context>
<context>
    <name>Header</name>
    <message>
        <location filename="../menu/Header.qml" line="6"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../menu/Header.qml" line="15"/>
        <source>Main menu</source>
        <translation>Ana menü</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <source>Your task is to transfer discs of different sizesfrom the left tower to any other free space.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation type="vanished">Göreviniz, sol kuleden farklı boyuttaki diskleri başka bir boş alana aktarmaktır. Kulenin sadece üst sürücüsünü aktarabilirsiniz. Birkaç diski aynı anda transfer edemez ve daha küçük disklere daha büyük diskler yerleştiremezsiniz.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="49"/>
        <source>Your task is to transfer discs of different sizesfrom the left tower to third tower.You can only transfer the top drive of the tower.You can not transfer several disks at once and put larger disks on small disks.</source>
        <translation>Göreviniz, sol kuleden farklı büyüklükteki diskleri üçüncü kuleye aktarmaktır. Yalnızca kulenin üst sürücüsünü aktarabilirsiniz. Aynı anda birkaç diski aktaramaz ve daha küçük disklere daha büyük diskler yerleştiremezsiniz.</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="62"/>
        <source>Do not show again:</source>
        <translation>Tekrar gösterme:</translation>
    </message>
    <message>
        <location filename="../Help.qml" line="90"/>
        <source>Ok</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>MainMenu</name>
    <message>
        <location filename="../menu/MainMenu.qml" line="21"/>
        <source>Hanoi Towers</source>
        <translation>Hanoi Kuleleri</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="69"/>
        <source>start</source>
        <translation>başlamak</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="82"/>
        <source>About</source>
        <translation>hakkında</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="95"/>
        <source>Config</source>
        <translation>ayarlar</translation>
    </message>
    <message>
        <location filename="../menu/MainMenu.qml" line="108"/>
        <source>exit</source>
        <translation>çıkış</translation>
    </message>
</context>
<context>
    <name>SwitchLvl</name>
    <message>
        <location filename="../SwitchLvl.qml" line="61"/>
        <source>Start</source>
        <translation>başla</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../about.qml" line="14"/>
        <source>about</source>
        <translation>hakkında</translation>
    </message>
    <message>
        <location filename="../about.qml" line="37"/>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018-2019 Yankovich N. Andrei.</source>
        <translation>QuasarApp ürünü
* Geliştiriciler:
* Programcı: Yankovich N. Andrei.
* Bu oyun LGPLv3 lisansı altında dağıtılmaktadır.
* İletişim: https://github.com/EndrII
* Telif Hakkı (C) 2018-2019 Yankovich N. Andrei.</translation>
    </message>
    <message>
        <source>Product of QuasarApp
* Developers:
* Programmer: Yankovich N. Andrei.
* This game is distributed under the LGPLv3 license.
* Contact: https://github.com/EndrII
* Copyright (C) 2018 Yankovich N. Andrei.</source>
        <translation type="vanished">QuasarApp ürünü
* Geliştiriciler:
* Programcı: Yankovich N. Andrei.
* Bu oyun LGPLv3 lisansı altında dağıtılmaktadır.
* İletişim: https://github.com/EndrII
* Telif Hakkı (C) 2018 Yankovich N. Andrei.</translation>
    </message>
</context>
<context>
    <name>game</name>
    <message>
        <source>Start</source>
        <translation type="vanished">başla</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="vanished">çıkış</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="vanished">hakkında</translation>
    </message>
    <message>
        <location filename="../game.qml" line="80"/>
        <source>lvl </source>
        <translation>seviye </translation>
    </message>
    <message>
        <location filename="../game.qml" line="104"/>
        <source>step </source>
        <translation>adım </translation>
    </message>
    <message>
        <location filename="../game.qml" line="69"/>
        <source>Tower height:</source>
        <translation>Kule yüksekliği:</translation>
    </message>
    <message>
        <location filename="../game.qml" line="115"/>
        <source>Return to main menu</source>
        <translation>Ana menüye dön</translation>
    </message>
    <message>
        <location filename="../game.qml" line="180"/>
        <source>You have passed the level in %0 steps and unlocked level %1
 Minimum steps for this lvl: %2</source>
        <translation>Seviyeyi %0 adımından geçirdiniz ve %1 kilidini açtınız
  Bu lvl için minimum adımlar: %2</translation>
    </message>
    <message>
        <location filename="../game.qml" line="187"/>
        <source>You have passed the level in %0 steps.
Minimum steps for this lvl: %1</source>
        <translation>Seviyeyi %0 adımından geçtiniz.
Bu lvl için minimum adımlar:%1</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">ok</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="9"/>
        <source>Hanoi Towers</source>
        <translation>Hanoi Kuleleri</translation>
    </message>
</context>
</TS>
